Useful tools to work with TigerGraph in Python

# Description
    
It consists of one module:

- `tghelper`: helper functions to work with TigerGraph and pyTigerGraph

# Installation
 
## Normal installation

```bash
pip install tghelper
```

## Development installation

```bash
git clone https://github.com/louisza/tghelper.git
cd tghelper
pip install --editable .
```